@@ -518,8 +518,10 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
                     repo.heads.crms_target.checkout()
 
                 ### DVC Pull
+                cwd = os.getcwd()
                 os.chdir(target)
                 p = subprocess.run(["dvc", "pull"])
+                os.chdir(cwd)
                 if p.returncode == 0 : # success of subprocess.run
                     print_verbose(verbose,"Pulled model files from DVC to " + target)
                 else: # fail of subprocess.run
@@ -608,8 +610,11 @@ def crms_clone(arg_model_url, arg_target='', verbose=False):
 
         # if arg_version == 'latest' : 
         ## only pull the latest version
+
+        cwd = os.getcwd()
         os.chdir(target)
         p = subprocess.run(["dvc", "pull"])
+        os.chdir(cwd)
         if p.returncode == 0 : # success of subprocess.run
             print_verbose(verbose,"Pulled model files from DVC to " + target)
         else: # fail of subprocess.run
@@ -727,6 +732,15 @@ def crms_list_cli(args):
         print(doc_id)
     print("CRMS LIST Completed !!!")
 
+CRMS_VERSION_STR = "0.19"
+
+def crms_ver(verbose=False):
+    print_verbose(verbose, "Print Version")
+    return CRMS_VERSION_STR
+
+def crms_ver_cli(args):
+    print(crms_ver(False))
+
 
 def crms(args):
     if args.cmd == 'conf':
@@ -747,6 +761,8 @@ def crms(args):
         crms_list_cli(args)
     elif args.cmd == 'desc' :
         crms_desc_cli(args)
+    elif args.cmd == 'version' :
+        crms_ver_cli(args)
     else :
         print("Unknown CMD")
 
@@ -765,6 +781,7 @@ def arg_parse() :
     parser_clone =  sub_parsers.add_parser('clone',  help="CRMS CLONE MODEL With Latest Version : crms clone <model_url> [--target=<target_dir>] ")
     parser_list =   sub_parsers.add_parser('list',  help="CRMS LIST Models : crms list")
     parser_desc =   sub_parsers.add_parser('desc',  help="CRMS DESCRIBE MODEL Versions : crms desc <model_name> ")
+    parser_ver  =   sub_parsers.add_parser('version',  help="CRMS Version Print : crms version")
 
     parser_conf.add_argument("git_remote", type=str,  action="store", help="git_remote_url is required")
     parser_conf.add_argument("dvc_remote", type=str,  action="store", help="dvc_remote_url is required")
